@@ -13,6 +13,8 @@
 
 import datetime
 import json
+import os
+import tempfile
 import unittest
 from unittest import mock
 
@@ -44,11 +46,16 @@ def _get_error(res):
 
 
 class BaseAPITest(test_base.BaseTest):
+
+    def init_app(self):
+        CONF.set_override('auth_strategy', 'noauth')
+        main._app.testing = True
+        self.app = main.get_app().test_client()
+        self.headers = {}
+
     def setUp(self):
         super(BaseAPITest, self).setUp()
-        main._app.config['TESTING'] = True
-        self.app = main._app.test_client()
-        CONF.set_override('auth_strategy', 'noauth')
+        self.init_app()
         self.uuid = uuidutils.generate_uuid()
         self.rpc_get_client_mock = self.useFixture(
             fixtures.MockPatchObject(rpc, 'get_client', autospec=True)).mock
@@ -57,10 +64,11 @@ class BaseAPITest(test_base.BaseTest):
 
 
 class TestApiIntrospect(BaseAPITest):
-    def test_introspect_no_authentication(self):
-        CONF.set_override('auth_strategy', 'noauth')
 
-        res = self.app.post('/v1/introspection/%s' % self.uuid)
+    def test_introspect(self):
+
+        res = self.app.post('/v1/introspection/%s' % self.uuid,
+                            headers=self.headers)
 
         self.assertEqual(202, res.status_code)
         self.client_mock.call.assert_called_once_with({}, 'do_introspection',
@@ -70,7 +78,8 @@ class TestApiIntrospect(BaseAPITest):
 
     def test_intospect_failed(self):
         self.client_mock.call.side_effect = utils.Error("boom")
-        res = self.app.post('/v1/introspection/%s' % self.uuid)
+        res = self.app.post('/v1/introspection/%s' % self.uuid,
+                            headers=self.headers)
 
         self.assertEqual(400, res.status_code)
         self.assertEqual(
@@ -82,7 +91,8 @@ class TestApiIntrospect(BaseAPITest):
                                                       token=None)
 
     def test_introspect_no_manage_boot(self):
-        res = self.app.post('/v1/introspection/%s?manage_boot=0' % self.uuid)
+        res = self.app.post('/v1/introspection/%s?manage_boot=0' % self.uuid,
+                            headers=self.headers)
         self.assertEqual(202, res.status_code)
         self.client_mock.call.assert_called_once_with({}, 'do_introspection',
                                                       node_id=self.uuid,
@@ -91,7 +101,8 @@ class TestApiIntrospect(BaseAPITest):
 
     def test_introspect_can_manage_boot_false(self):
         CONF.set_override('can_manage_boot', False)
-        res = self.app.post('/v1/introspection/%s?manage_boot=0' % self.uuid)
+        res = self.app.post('/v1/introspection/%s?manage_boot=0' % self.uuid,
+                            headers=self.headers)
         self.assertEqual(202, res.status_code)
         self.client_mock.call.assert_called_once_with({}, 'do_introspection',
                                                       node_id=self.uuid,
@@ -100,12 +111,14 @@ class TestApiIntrospect(BaseAPITest):
 
     def test_introspect_can_manage_boot_false_failed(self):
         CONF.set_override('can_manage_boot', False)
-        res = self.app.post('/v1/introspection/%s' % self.uuid)
+        res = self.app.post('/v1/introspection/%s' % self.uuid,
+                            headers=self.headers)
         self.assertEqual(400, res.status_code)
         self.assertFalse(self.client_mock.call.called)
 
     def test_introspect_wrong_manage_boot(self):
-        res = self.app.post('/v1/introspection/%s?manage_boot=foo' % self.uuid)
+        res = self.app.post('/v1/introspection/%s?manage_boot=foo' % self.uuid,
+                            headers=self.headers)
         self.assertEqual(400, res.status_code)
         self.assertFalse(self.client_mock.call.called)
         self.assertEqual(
@@ -122,6 +135,30 @@ class TestApiIntrospect(BaseAPITest):
         self.assertFalse(self.client_mock.call.called)
 
 
+class TestBasicAuthApiIntrospect(TestApiIntrospect):
+
+    def init_app(self):
+        CONF.set_override('auth_strategy', 'http_basic')
+        with tempfile.NamedTemporaryFile(mode='w', delete=False) as f:
+            f.write('myName:$2y$05$lE3eGtyj41jZwrzS87KTqe6.'
+                    'JETVCWBkc32C63UP2aYrGoYOEpbJm\n\n\n')
+            self.addCleanup(os.remove, f.name)
+            CONF.set_override('http_basic_auth_user_file', f.name)
+        main._app.config['TESTING'] = True
+        self.app = main.get_app().test_client()
+
+        # base64 encode myName:myPassword
+        self.headers = {'Authorization': 'Basic bXlOYW1lOm15UGFzc3dvcmQ='}
+
+    def test_introspect_failed_authentication(self):
+        # base64 encode myName:yourPassword
+        self.headers = {'Authorization': 'Basic bXlOYW1lOnlvdXJQYXNzd29yZA=='}
+
+        res = self.app.post('/v1/introspection/%s' % self.uuid,
+                            headers=self.headers)
+        self.assertEqual(401, res.status_code)
+
+
 class TestApiContinue(BaseAPITest):
     def test_continue(self):
         # should be ignored
@@ -417,7 +454,7 @@ class TestApiReapply(BaseAPITest):
 
 
 class TestApiRules(BaseAPITest):
-    @mock.patch.object(rules, 'get_all')
+    @mock.patch.object(rules, 'get_all', autospec=True)
     def test_get_all(self, get_all_mock):
         get_all_mock.return_value = [
             mock.Mock(spec=rules.IntrospectionRule,
@@ -444,7 +481,7 @@ class TestApiRules(BaseAPITest):
         for m in get_all_mock.return_value:
             m.as_dict.assert_called_with(short=True)
 
-    @mock.patch.object(rules, 'delete_all')
+    @mock.patch.object(rules, 'delete_all', autospec=True)
     def test_delete_all(self, delete_all_mock):
         res = self.app.delete('/v1/rules')
         self.assertEqual(204, res.status_code)
@@ -501,7 +538,7 @@ class TestApiRules(BaseAPITest):
         res = self.app.post('/v1/rules', data=json.dumps(data))
         self.assertEqual(400, res.status_code)
 
-    @mock.patch.object(rules, 'get')
+    @mock.patch.object(rules, 'get', autospec=True)
     def test_get_one(self, get_mock):
         get_mock.return_value = mock.Mock(spec=rules.IntrospectionRule,
                                           **{'as_dict.return_value':
@@ -517,7 +554,7 @@ class TestApiRules(BaseAPITest):
         get_mock.assert_called_once_with(self.uuid)
         get_mock.return_value.as_dict.assert_called_once_with(short=False)
 
-    @mock.patch.object(rules, 'delete')
+    @mock.patch.object(rules, 'delete', autospec=True)
     def test_delete_one(self, delete_mock):
         res = self.app.delete('/v1/rules/' + self.uuid)
         self.assertEqual(204, res.status_code)
@@ -703,7 +740,7 @@ class TestTopic(test_base.BaseTest):
         self.target_mock.assert_called_with(
             topic='hello', version=mock.ANY)
 
-    @mock.patch.object(coordination, 'get_coordinator')
+    @mock.patch.object(coordination, 'get_coordinator', autospec=True)
     def test_get_random_topic(self, mock_get_coordinator):
         mock_coordinator = mock.Mock(spec=['get_members'])
         members = [('ironic_inspector.conductor.host%s' % i).encode('ascii')
@@ -715,7 +752,7 @@ class TestTopic(test_base.BaseTest):
             topic = main.get_random_topic()
             self.assertIn(topic, topics)
 
-    @mock.patch.object(coordination, 'get_coordinator')
+    @mock.patch.object(coordination, 'get_coordinator', autospec=True)
     def test_get_random_topic_host_with_domain(self, mock_get_coordinator):
         mock_coordinator = mock.Mock(spec=['get_members'])
         members = ['ironic_inspector.conductor.'
@@ -725,7 +762,7 @@ class TestTopic(test_base.BaseTest):
         topic = main.get_random_topic()
         self.assertEqual(topic, 'ironic_inspector.conductor.local.domain')
 
-    @mock.patch.object(coordination, 'get_coordinator')
+    @mock.patch.object(coordination, 'get_coordinator', autospec=True)
     def test_get_random_topic_host_bypass_invalid(self, mock_get_coordinator):
         mock_coordinator = mock.Mock(spec=['get_members'])
         members = ['this_should_not_happen'.encode('ascii')]
@@ -735,7 +772,7 @@ class TestTopic(test_base.BaseTest):
                                'No available conductor',
                                main.get_random_topic)
 
-    @mock.patch.object(coordination, 'get_coordinator')
+    @mock.patch.object(coordination, 'get_coordinator', autospec=True)
     def test_get_random_topic_no_member(self, mock_get_coordinator):
         mock_coordinator = mock.Mock(spec=['get_members'])
         mock_coordinator.get_members.return_value = set()
