@@ -15,8 +15,9 @@ import datetime
 import logging as pylog
 
 import futurist
-from ironicclient.v1 import node
+from ironic_lib import auth_basic
 from keystonemiddleware import auth_token
+from openstack.baremetal.v1 import node
 from oslo_config import cfg
 from oslo_log import log
 from oslo_middleware import cors as cors_middleware
@@ -187,6 +188,15 @@ def add_auth_middleware(app):
     app.wsgi_app = auth_token.AuthProtocol(app.wsgi_app, auth_conf)
 
 
+def add_basic_auth_middleware(app):
+    """Add HTTP Basic authentication middleware to Flask application.
+
+    :param app: application.
+    """
+    app.wsgi_app = auth_basic.BasicAuthMiddleware(
+        app.wsgi_app, CONF.http_basic_auth_user_file)
+
+
 def add_cors_middleware(app):
     """Create a CORS wrapper
 
@@ -203,9 +213,10 @@ def check_auth(request, rule=None, target=None):
 
     :param request: Flask request
     :param rule: policy rule to check the request against
+    :param target: dict-like structure to check rule against
     :raises: utils.Error if access is denied
     """
-    if CONF.auth_strategy == 'noauth':
+    if CONF.auth_strategy != 'keystone':
         return
     if not request.context.is_public_api:
         if request.headers.get('X-Identity-Status', '').lower() == 'invalid':
